@@ -19,13 +19,13 @@
 #include <QVBoxLayout>
 
 // KDE
-#include <kconfig.h>
-#include <kconfiggroup.h>
-#include <kiconbutton.h>
-#include <kicondialog.h>
-#include <klineedit.h>
-#include <klocalizedstring.h>
-#include <ksharedconfig.h>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KIconButton>
+#include <KIconDialog>
+#include <KLineEdit>
+#include <KLocalizedString>
+#include <KSharedConfig>
 
 // Local
 #include "kservicelistwidget.h"
@@ -119,6 +119,7 @@ FileTypeDetails::FileTypeDetails(QWidget *parent)
 
     serviceListWidget = new KServiceListWidget(KServiceListWidget::SERVICELIST_APPLICATIONS, firstWidget);
     connect(serviceListWidget, &KServiceListWidget::changed, this, &FileTypeDetails::changed);
+    connect(serviceListWidget, &KServiceListWidget::multiApply, this, &FileTypeDetails::multiApply);
     firstLayout->addWidget(serviceListWidget, 5);
 
     // Second tab - Embedding
@@ -141,7 +142,7 @@ FileTypeDetails::FileTypeDetails(QWidget *parent)
     m_autoEmbedGroup->addButton(embViewerRadio, 0);
     m_autoEmbedGroup->addButton(sepViewerRadio, 1);
     m_autoEmbedGroup->addButton(m_rbGroupSettings, 2);
-    connect(m_autoEmbedGroup, SIGNAL(buttonClicked(int)), SLOT(slotAutoEmbedClicked(int)));
+    connect(m_autoEmbedGroup, &QButtonGroup::idClicked, this, &FileTypeDetails::slotAutoEmbedClicked);
 
     vbox = new QVBoxLayout(m_autoEmbedBox);
     vbox->addWidget(embViewerRadio);
@@ -160,6 +161,7 @@ FileTypeDetails::FileTypeDetails(QWidget *parent)
     embedServiceListWidget = new KServiceListWidget(KServiceListWidget::SERVICELIST_SERVICES, secondWidget);
     //  embedServiceListWidget->setMinimumHeight( serviceListWidget->sizeHint().height() );
     connect(embedServiceListWidget, &KServiceListWidget::changed, this, &FileTypeDetails::changed);
+    connect(embedServiceListWidget, &KServiceListWidget::multiApply, this, &FileTypeDetails::multiApply);
     secondLayout->addWidget(embedServiceListWidget);
 
     m_tabWidget->addTab(firstWidget, i18n("&General"));
@@ -360,3 +362,11 @@ void FileTypeDetails::refresh()
     m_mimeTypeData->refresh();
     setMimeTypeData(m_mimeTypeData, m_item);
 }
+
+void FileTypeDetails::allowMultiApply(bool allow)
+{
+    serviceListWidget->allowMultiApply(allow);
+    embedServiceListWidget->allowMultiApply(allow);
+}
+
+#include "moc_filetypedetails.cpp"
